within FluidDissipation.Examples.Verifications.HeatTransfer.HeatExchanger;
model kc_tubeBundle_1ph "Verification of function kc_tubeBundle_1ph"

  parameter Integer n=size(cp, 1) "number of fluids";

  //Heat exchanger variables
  parameter Modelica.SIunits.Area A_front(min=1e-6)=1
    "Cross sectional area in front of the tube row or bundle";
  parameter Modelica.SIunits.Length d(min=1e-6) = 0.0164
    "Outer diameter of tubes";
//   parameter Modelica.SIunits.Length s_1(min=d + 1e-6) = 0.0164
//     "Distance between tubes (center to center) orthogonal to flow direction";
//   parameter Modelica.SIunits.Length s_2(min=0) = 0.0164
//     "Distance between tubes (center to center) parallel to flow direction";
protected
  parameter SI.Length s[2]={d*2, d*1.25};

public
  Integer n_rows(min=1) = 7 "Number of pipe rows in flow direction";

protected
  parameter Modelica.SIunits.Length L = Modelica.Constants.pi*d;

public
  SI.PrandtlNumber Pr[n]={eta[i]*cp[i]/(lambda[i]) for i in 1:n};
  SI.ReynoldsNumber Re=input_Re.y;
  //SI.Velocity velocity[n]={m_flow[i]/(rho[i]*h*s) for i in 1:n};

  //fluid property variables
  parameter SI.SpecificHeatCapacityAtConstantPressure cp[:]={1007,4189,3384.550}
    "Specific heat capacity at constant pressure of fluid";
  parameter SI.DynamicViscosity eta[:]={18.04e-6,1001.6e-6,0.114}
    "Dynamic viscosity of fluid";
  parameter SI.ThermalConductivity lambda[:]={25.3e-3,598.5e-3,0.387}
    "Thermal conductivity of fluid";
  parameter SI.Density rho[:]={1.217,998.21,1037.799} "Density of fluid";

  parameter SI.SpecificHeatCapacityAtConstantPressure cp_w[:]={1010,4189,3384.550}
    "Specific heat capacity at constant pressure of fluid";
  parameter SI.DynamicViscosity eta_w[:]={18.04e-6,1001.6e-6,0.114}
    "Dynamic viscosity of fluid";
  parameter SI.ThermalConductivity lambda_w[:]={29.66e-3,598.5e-3,0.387}
    "Thermal conductivity of fluid";
  parameter SI.Density rho_w[:]={1.000,998.21,1037.799} "Density of fluid";

  //input variables
  //SI.ReynoldsNumber Re = input_Re.y "Reynolds number" annotation (Dialog(group="Input"));

  //input records

  //output variables
  SI.MassFlowRate[n] m_flow = Re*A_front/d*eta "Mass flow rate" annotation (Dialog(group="Output"));
  SI.NusseltNumber[n] Nu_1 "Nusselt number" annotation (Dialog(group="Output"));
  SI.NusseltNumber[n] Nu_d_1 "Nusselt number" annotation (Dialog(group="Output"));
  SI.CoefficientOfHeatTransfer[n] kc_1 "Heat transfer coefficient";
  SI.NusseltNumber[n] Nu_2 "Nusselt number" annotation (Dialog(group="Output"));
  SI.NusseltNumber[n] Nu_d_2 "Nusselt number" annotation (Dialog(group="Output"));
  SI.CoefficientOfHeatTransfer[n] kc_2 "Heat transfer coefficient";
  SI.ReynoldsNumber[n] Re_1 "Reynolds number" annotation (Dialog(group="Output"));
  SI.ReynoldsNumber[n] Re_2 "Reynolds number" annotation (Dialog(group="Output"));

public
  Modelica.Blocks.Sources.Ramp input_Re(
    duration=1,
    startTime=0,
    offset=1,
    height=1000000)
              annotation (Placement(transformation(
          extent={{-80,-80},{-60,-60}})));

  FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph_IN_con
                                                                 m_flow_IN_con_1[n](
    each A_front=A_front,
    each d=d,
    each staggeredAlignment=true,
    each s_1=s[1],
    each s_2=s[1],
    each n=n_rows)
    annotation (Placement(transformation(extent={{-70,-8},{-50,12}})));
  FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph_IN_var
                                                                 m_flow_IN_var_1[n](
    m_flow=m_flow*(1 - Modelica.Constants.pi/4/s[1]*d)/Modelica.Constants.pi*2,
    cp=cp,
    eta=eta,
    lambda=lambda,
    rho=rho,
    cp_w=cp_w,
    eta_w=eta_w,
    lambda_w=lambda_w)
                  annotation (Placement(transformation(extent={{-50,-8},{-30,12}})));
  FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph_IN_con
                                                                 m_flow_IN_con_2[n](
    each A_front=A_front,
    each d=d,
    each s_1=s[2],
    each s_2=s[2],
    each n=n_rows,
    each staggeredAlignment=false)
    annotation (Placement(transformation(extent={{30,-8},{50,12}})));
  FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph_IN_var
                                                                 m_flow_IN_var_2[n](
    m_flow=m_flow*(1 - Modelica.Constants.pi/4/s[2]*d)/Modelica.Constants.pi*2,
    cp=cp,
    eta=eta,
    lambda=lambda,
    rho=rho,
    cp_w=cp_w,
    eta_w=eta_w,
    lambda_w=lambda_w)
                  annotation (Placement(transformation(extent={{50,-8},{70,12}})));
equation
  for i in 1:n loop
  //heat transfer calculation
  (kc_1[i],,Re_1[i],Nu_1[i]) =
   FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph(
    m_flow_IN_con_1[i], m_flow_IN_var_1[i]);
  (kc_2[i],,Re_2[i],Nu_2[i]) =
    FluidDissipation.HeatTransfer.HeatExchanger.kc_tubeBundle_1ph(
    m_flow_IN_con_2[i], m_flow_IN_var_2[i]);
  end for;

  Nu_d_1 = Nu_1/L*d;
  Nu_d_2 = Nu_2/L*d;

  annotation (Diagram(graphics={
           Text(
          extent={{-100,50},{100,75}},
          lineColor={0,0,255},
          textString=
              "Heat transfer of heat exchanger tube bundles and SINGLE phase fluids "),
                                                                          Text(
          extent={{-150,21},{50,16}},
          lineColor={0,0,255},
          textString="staggered tubes"),                                  Text(
          extent={{-50,21},{150,16}},
          lineColor={0,0,255},
          textString="in-line tubes")}),
          Commands(file="modelica://FluidDissipation/Extras/Scripts/heatTransfer/heatExchanger/kc_FilmCondensationTubeBundle.mos"
        "Verification of kc_FilmCondensationTubeBundle"),
    experiment(Interval=2e-005),
    __Dymola_experimentSetupOutput);
end kc_tubeBundle_1ph;
